summaryrefslogtreecommitdiffabout
path: root/libkcal/dndfactory.h
authorzautrix <zautrix>2005-01-29 23:23:11 (UTC)
committer zautrix <zautrix>2005-01-29 23:23:11 (UTC)
commitd94b52aa95cc52aa1bef7c9cd99f43c725ed8042 (patch) (side-by-side diff)
tree9443dfbc790a76e5d707ce762e075cdb21096f50 /libkcal/dndfactory.h
parent74c808f288bf81bc68c92a377ce64953603c2d40 (diff)
downloadkdepimpi-d94b52aa95cc52aa1bef7c9cd99f43c725ed8042.zip
kdepimpi-d94b52aa95cc52aa1bef7c9cd99f43c725ed8042.tar.gz
kdepimpi-d94b52aa95cc52aa1bef7c9cd99f43c725ed8042.tar.bz2
todo dnd
Diffstat (limited to 'libkcal/dndfactory.h') (more/less context) (ignore whitespace changes)
-rw-r--r--libkcal/dndfactory.h56
1 files changed, 34 insertions, 22 deletions
diff --git a/libkcal/dndfactory.h b/libkcal/dndfactory.h
index 6b73f34..7e2ca04 100644
--- a/libkcal/dndfactory.h
+++ b/libkcal/dndfactory.h
@@ -1,7 +1,9 @@
/*
This file is part of libkcal.
+
Copyright (c) 1998 Preston Brown
- Copyright (c) 2001,2002 Cornelius Schumacher <schumacher@kde.org>
+ Copyright (c) 2001,2002,2003 Cornelius Schumacher <schumacher@kde.org>
+ Copyright (C) 2003-2004 Reinhold Kainhofer <reinhold@kainhofer.com>
This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Library General Public
@@ -19,42 +21,52 @@
Boston, MA 02111-1307, USA.
*/
-// $Id$
-
#ifndef KCAL_DNDFACTORY_H
#define KCAL_DNDFACTORY_H
-#include "vcalformat.h"
-
-class QDropEvent;
+//#include "libkcal_export.h"
namespace KCal {
+class ICalDrag;
+class Event;
+class Todo;
+class Calendar;
+#define LIBKCAL_EXPORT
+
/**
This class implements functions to create Drag and Drop objects used for
Drag-and-Drop and Copy-and-Paste.
- @short vCalendar Drag-and-Drop object factory.
+ @short vCalendar/iCalendar Drag-and-Drop object factory.
*/
-class DndFactory {
+class LIBKCAL_EXPORT DndFactory
+{
public:
- DndFactory( Calendar * ) {}
+ DndFactory( Calendar * );
+
+ /**
+ Create a drag object.
+ */
+ ICalDrag *createDrag( Incidence *incidence, QWidget *owner );
- /** create an object to be used with the Xdnd Drag And Drop protocol. */
- ICalDrag *createDrag(Event *, QWidget *) { return 0; }
- /** create an object to be used with the Xdnd Drag And Drop protocol. */
- ICalDrag *createDragTodo(Todo *, QWidget *) { return 0; }
/** Create Todo object from drop event */
- Todo *createDropTodo(QDropEvent *) { return 0; }
+ Todo *createDropTodo(QDropEvent *de);
/** Create Event object from drop event */
- Event *createDrop(QDropEvent *) { return 0; }
-
- /** cut event to clipboard */
- void cutEvent(Event *) {}
- /** cut, copy, and paste operations follow. */
- bool copyEvent(Event *) { return false; }
- /** pastes the event and returns a pointer to the new event pasted. */
- Event *pasteEvent(const QDate &, const QTime *newTime = 0) { return 0; }
+ Event *createDrop(QDropEvent *de);
+
+ /** cut incidence to clipboard */
+ void cutIncidence( Incidence * );
+ /** copy the incidence to clipboard */
+ bool copyIncidence( Incidence * );
+ /** pastes the event or todo and returns a pointer to the new incidence pasted. */
+ Incidence *pasteIncidence( const QDate &, const QTime *newTime = 0 );
+
+ private:
+ Calendar *mCalendar;
+
+ class Private;
+ Private *d;
};
}